@@ -7,7 +7,7 @@ use Digest::Haval256;
 use MIME::Base64;
 
 my $file = "strings.pl";
-open INFILE, $file;
+open INFILE, $file or die "$file not found";
 
 my $haval = new Digest::Haval256;
 $haval->addfile(*INFILE);
